<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\AttendanceResource;
use App\Models\Attendance;
use Illuminate\Http\Request;

class AttendanceController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $attendances = Attendance::with("user", "franchise")
            ->filter()->latest()->paginate($perPage);

        return AttendanceResource::collection($attendances);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required'],
            'franchise_id' => ['required'],
            'date_time' => ['sometimes',],
            'remark' => ['sometimes'],
        ]);

        return new AttendanceResource(Attendance::create($data));
    }

    public function show(Attendance $attendance) {
        return new AttendanceResource($attendance->loadMissing("user", "franchise"));
    }

    public function update(Request $request, Attendance $attendance) {
        $data = $request->validate([
            'user_id' => ['sometimes'],
            'franchise_id' => ['sometimes'],
            'date_time' => ['sometimes'],
            'remark' => ['sometimes'],
        ]);

        $attendance->update($data);

        return new AttendanceResource($attendance);
    }

    public function destroy(Attendance $attendance) {
        $attendance->delete();

        return response()->json(["message" => "Attendance deleted successfully!"]);
    }
}
