<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ExpenseResource;
use App\Models\Expense;
use Illuminate\Http\Request;

class ExpenseController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $expenses = Expense::with(["franchise", "expenseType"])
            ->filter()->latest()->paginate($perPage);

        return ExpenseResource::collection($expenses);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'expense_type_id' => ['required'],
            'franchise_id' => ['required'],
            'name' => ['required'],
            'amount' => ['required'],
        ]);

        return response()->json(
            new ExpenseResource(Expense::create($data)), 201
        );
    }

    public function show(Expense $expense) {
        return new ExpenseResource($expense->loadMissing(["franchise", "expenseType"]));
    }

    public function update(Request $request, Expense $expense) {
        $data = $request->validate([
            'expense_type_id' => ['sometimes'],
            'franchise_id' => ['sometimes'],
            'name' => ['sometimes'],
            'amount' => ['sometimes'],
        ]);

        $expense->update($data);

        return new ExpenseResource($expense);
    }

    public function destroy(Expense $expense) {
        $expense->delete();
        return response()->json(["message" => "Expense deleted successfully!"]);
    }
}
