<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ExpenseTypeResource;
use App\Models\ExpenseType;
use Illuminate\Http\Request;

class ExpenseTypeController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $expenseTypes = ExpenseType::with(["franchise", "expenses"])
            ->filter()->latest()->paginate($perPage);

        return ExpenseTypeResource::collection($expenseTypes);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => ['required'],
            'name' => ['required'],
        ]);

        return new ExpenseTypeResource(ExpenseType::create($data));
    }

    public function show(ExpenseType $expenseType) {
        return new ExpenseTypeResource(
            $expenseType->loadMissing(["franchise", "expenses"])
        );
    }

    public function update(Request $request, ExpenseType $expenseType) {
        $data = $request->validate([
            'franchise_id' => ['sometimes'],
            'name' => ['sometimes'],
        ]);

        $expenseType->update($data);

        return new ExpenseTypeResource($expenseType);
    }

    public function destroy(ExpenseType $expenseType) {
        $expenseType->delete();

        return response()->json(["message", "Expense type deleted successfully!"]);
    }
}
