<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ItemResource;
use App\Http\Traits\HasStoreFile;
use App\Models\Item;
use Illuminate\Http\Request;

class ItemController extends Controller
{
    use HasStoreFile;

    // path of the folder where files related to the controller will be stored
    protected string $folderPath = "items";

    // name of the field for file upload in the model
    protected string $fileField = "image";

    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $items = Item::with("franchise")
            ->filter()->latest()->paginate($perPage);

        return ItemResource::collection($items);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => 'required',
            'name' => 'required|string',
            'qty' => 'required',
            'type' => 'required|string',
            'image' => 'sometimes|file|mimes:jpeg,jpg,png,gif|max:2048',
        ]);

        $item = Item::create($data);

        if ($request->hasFile($this->fileField)) {
            $item->image = $this->storeFile($request, $this->fileField, $this->folderPath);
            $item->save();
        }

        return response()->json(
            new ItemResource($item), 201
        );
    }

    public function show(Item $item) {
        return new ItemResource($item->loadMissing("franchise"));
    }

    public function update(Request $request, Item $item) {
        $data = $request->validate([
            'franchise_id' => 'sometimes',
            'name' => 'sometimes|string',
            'qty' => 'sometimes',
            'type' => 'sometimes|string',
            'image' => 'sometimes|file|mimes:jpeg,jpg,png,gif|max:2048',
        ]);

        $item->fill($data);
        if ($request->hasFile($this->fileField)) {
            $this->deleteFile($this->folderPath, $item[$this->fileField]);
            $item[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $item->save();

        return new ItemResource($item);
    }

    public function destroy(Item $item) {
        $this->deleteFile($this->folderPath, $item[$this->fileField]);
        $item->delete();

        return response()->json(["message" => "Item deleted successfully!"]);
    }
}
