<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\MasterFranchiseResource;
use App\Http\Traits\HasStoreFile;
use App\Models\MasterFranchise;
use App\Models\User;
use Illuminate\Http\Request;

class MasterFranchiseController extends Controller
{
    // path of the folder where files related to the controller will be stored
    protected string $folderPath = "master-franchises";

    // name of the field for file upload in the model
    protected string $fileField = "photo";

    use HasStoreFile;

    public function index(Request $request) {
        $perPage = $request->query("perPage") ?? 10;
        $masterFranchises = MasterFranchise::query()->filter()->latest()->paginate($perPage);
        return MasterFranchiseResource::collection($masterFranchises);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'name' => ['required'],
            'email' => ['required', 'email', "unique:users,email", 'max:254'],
            'phone' => ['required'],
            'password' => ["required", "string", "confirmed"],
            "password_confirmation" => ["required", "same:password"],
            'photo' => ['nullable', "file", "mimes:jpeg,png,jpg,gif", "max:2048"],
        ]);

        $masterFranchise = MasterFranchise::create($data);
        if ($request->hasFile($this->fileField)) {
            $masterFranchise->photo = $this->storeFile($request, $this->fileField, $this->folderPath);
            $masterFranchise->save();
        }

        // TODO: need to create a franchise model with is_master property true

        User::create([
            "name" => $request->name,
            "email" => $request->email,
            "mobile_no" => $request->phone,
            "password" => $request->password,
            "role" => "master franchise",
            "master_franchise_id" => $masterFranchise->id
        ]);

        return response()->json(
            new MasterFranchiseResource($masterFranchise->loadMissing("user")), 201
        );
    }

    public function show(MasterFranchise $franchiseMaster) {
        // TODO: following line should be implemented instead of current
        // $masterFranchiseUsers = User::where("master_franchise_id", $franchiseMaster->id)
        //        ->where("role", "master franchise")->get();

        return new MasterFranchiseResource($franchiseMaster->loadMissing("user"));
    }

    public function update(Request $request, MasterFranchise $franchiseMaster) {
        $data = $request->validate([
            'name' => ['sometimes'],
            'email' => ['sometimes', 'email', "unique:users,email", 'max:254'],
            'phone' => ['sometimes'],
            'photo' => ['sometimes', "file", "mimes:jpeg,png,jpg,gif", "max:2048"],
        ]);

        $franchiseMaster->fill($data);
        if ($request->hasFile($this->fileField)) {
            $this->deleteFile($this->folderPath, $franchiseMaster[$this->fileField]);
            $franchiseMaster[$this->fileField] = $this->storeFile($request, $this->fileField, $this->folderPath);
        }
        $franchiseMaster->save();

        $franchiseMasterUser = User::where("master_franchise_id", $franchiseMaster->id)->first();
        $franchiseMasterUser->update($data);

        return new MasterFranchiseResource($franchiseMaster->loadMissing("user"));
    }

    public function destroy(MasterFranchise $franchiseMaster) {
        // delete file from the storage
        $this->deleteFile($this->folderPath, $franchiseMaster->photo);

        $franchiseMaster->delete();
        return response()->json(["message" => "Master franchise deleted successfully!"]);
    }
}
