<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\OrderSourceResource;
use App\Models\OrderSource;
use Illuminate\Http\Request;

class OrderSourceController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $orderSources = OrderSource::with("franchise")
            ->filter()->latest()->paginate($perPage);

        return OrderSourceResource::collection($orderSources);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => ['required'],
            'name' => ['required'],
        ]);

        return new OrderSourceResource(OrderSource::create($data));
    }

    public function show(OrderSource $orderSource) {
        return new OrderSourceResource($orderSource->loadMissing("franchise"));
    }

    public function update(Request $request, OrderSource $orderSource) {
        $data = $request->validate([
            'franchise_id' => ['nullable', 'exists:franchises'],
            'name' => ['nullable'],
        ]);

        $orderSource->update($data);

        return new OrderSourceResource($orderSource);
    }

    public function destroy(OrderSource $orderSource) {
        $orderSource->delete();

        return response()->json(["message" => "Order source deleted successfully!"]);
    }
}
