<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseOrderResource;
use App\Models\Item;
use App\Models\PurchaseOrder;
use App\Models\PurchaseOrderDetail;
use Illuminate\Http\Request;

class PurchaseOrderController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $purchaseOrders = PurchaseOrder::with(["purchaseOrderDetails.item", "franchise",])
            ->filter()->latest()->paginate($perPage);

        return PurchaseOrderResource::collection($purchaseOrders);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => ['required', 'exists:franchises'],
            'vendor_name' => ['required'],
            'total' => ['required'],
            'date' => ['sometimes'],
            'type' => ['sometimes'],
            'paid_date' => ['sometimes'],
            'is_paid' => ["required", 'boolean'],
            "purchase_order_details" => ["sometimes", "array"]
        ]);

        $purchaseOrder = PurchaseOrder::create($data);

        // TODO: what's going on ?
        if ($request->has("purchase_order_details")) {
            foreach ($request->purchase_order_details as $order_detail) {
                $purchaseOrderDetail = new PurchaseOrderDetail();
                $purchaseOrderDetail->fill($order_detail);
                $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;
                $purchaseOrderDetail->save();

                if ($purchaseOrder->is_paid) {
                    $item = Item::findOrFail($purchaseOrderDetail->item_id);
                    $item->qty += (int) $purchaseOrderDetail->qty;
                    $item->save();
                }
            }
        }

        return new PurchaseOrderResource($purchaseOrder);
    }

    public function show(PurchaseOrder $purchaseOrder) {
        return new PurchaseOrderResource(
            $purchaseOrder->loadMissing(["purchaseOrderDetails.item", "franchise"])
        );
    }

    public function update(Request $request, PurchaseOrder $purchaseOrder) {
        $data = $request->validate([
            'franchise_id' => ['sometimes', "string"],
            'vendor_name' => ['sometimes', "string"],
            'total' => ['sometimes'],
            'date' => ['sometimes'],
            'type' => ['sometimes'],
            'paid_date' => ['sometimes'],
            'is_paid' => ["sometimes", 'boolean'],
            "purchase_order_details" => ['sometimes'],
            "delete_purchase_order_detail_ids" => ["sometimes", "array"],
        ]);
        $purchaseOrder->update($data);

        if ($request->has("purchase_order_details")) {
            foreach ($request->purchase_order_details as $order_detail) {
                if (!isset($order_detail->id)) {
                    $purchaseOrderDetail = new PurchaseOrderDetail;
                    $purchaseOrderDetail->fill($order_detail);
                    $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;

                    if ($purchaseOrder->is_paid) {
                        $item = Item::findOrFail($purchaseOrderDetail->item_id);
                        $item->qty += (int) $purchaseOrderDetail->qty;
                        $item->save();
                    }
                }

                $purchaseOrderDetail = PurchaseOrderDetail::findOrFail($order_detail->id);
                $oldQty = $purchaseOrderDetail->qty;
                $purchaseOrderDetail->fill($order_detail);
                $purchaseOrderDetail->purchase_order_id = $purchaseOrder->id;
                $purchaseOrderDetail->save();

                $item = Item::findOrFail($purchaseOrderDetail->item_id);
                $item->qty += abs(((int) $oldQty) - ((int) $purchaseOrderDetail->qty));
                $item->save();
            }
        }

        if ($request->has("delete_purchase_order_detail_ids")) {
            foreach ($request->delete_purchase_order_detail_ids as $id) {
                $purchaseOrderDetail = PurchaseOrderDetail::findOrFail($id);
                $item = Item::findOrFail($purchaseOrderDetail->item_id);
                $item->qty -= $purchaseOrderDetail->qty;
                $item->save();
            }
            PurchaseOrderDetail::whereIn("id", $request->delete_purchase_order_detail_ids)->delete();
        }

        return new PurchaseOrderResource($purchaseOrder);
    }

    public function destroy(PurchaseOrder $purchaseOrder) {
        PurchaseOrderDetail::where("purchase_order_id", $purchaseOrder->id)->delete();
        $purchaseOrder->delete();

        return response()->json(["message" => "Purchase Order deleted successfully!"]);
    }
}
