<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\TableResource;
use App\Models\Table;
use Illuminate\Http\Request;

class TableController extends Controller
{
    public function index(Request $request) {
        $perPage = $request->perPage ?? 10;
        $tables = Table::with("franchise")
            ->filter()->latest()->paginate($perPage);

        return TableResource::collection($tables);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => ['required'],
            'master_franchise_id' => ['sometimes'],
            'name' => ['required'],
            'status' => ['required', 'boolean'],
        ]);

        return response()->json(
            new TableResource(Table::create($data)), 201
        );
    }

    public function show(Table $table) {
        return new TableResource($table->loadMissing("franchise"));
    }

    public function update(Request $request, Table $table) {
        $data = $request->validate([
            'franchise_id' => ['sometimes'],
            'master_franchise_id' => ['sometimes'],
            'name' => ['sometimes'],
            'status' => ['sometimes', 'boolean'],
        ]);

        $table->update($data);

        return new TableResource($table);
    }

    public function destroy(Table $table) {
        $table->delete();

        return response()->json([
            "message" => "Table deleted successfully!"
        ]);
    }
}
