<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\TicketResource;
use App\Models\Ticket;
use Illuminate\Http\Request;

class TicketController extends Controller
{
    public function index() {
        return TicketResource::collection(Ticket::all());
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users'],
            'franchise_id' => ['required', 'exists:franchises'],
            'subject' => ['nullable'],
            'message' => ['nullable'],
            'file' => ['nullable'],
            'resolved_date' => ['nullable'],
            'remarks' => ['nullable'],
        ]);

        return new TicketResource(Ticket::create($data));
    }

    public function show(Ticket $ticket) {
        return new TicketResource($ticket);
    }

    public function update(Request $request, Ticket $ticket) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users'],
            'franchise_id' => ['required', 'exists:franchises'],
            'subject' => ['nullable'],
            'message' => ['nullable'],
            'file' => ['nullable'],
            'resolved_date' => ['nullable'],
            'remarks' => ['nullable'],
        ]);

        $ticket->update($data);

        return new TicketResource($ticket);
    }

    public function destroy(Ticket $ticket) {
        $ticket->delete();

        return response()->json();
    }
}
