<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\UserResource;
use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    public function index(Request $request) {
        $search = $request->query("search");
        $perPage = $request->perPage ?? 10;
        $users = User::with("franchise")
            ->filter()->latest()->paginate($perPage);

        return UserResource::collection($users);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'master_franchise_id' => 'sometimes',
            'franchise_id' => 'required',
            "mobile_no" => 'required|string',
            'name' => 'required|string',
            'email' => 'required|email|max:254',
            'password' => 'required|confirmed|string',
            'password_confirmation' => "required",
            'role' => 'required|string',
            'designation' => 'required|string',
        ]);

        return response()->json(
            new UserResource(User::create($data)), 201
        );
    }

    public function show(User $user) {
        return new UserResource($user->loadMissing("franchise"));
    }

    public function update(Request $request, User $user) {
        $request->validate([
            'master_franchise_id' => 'sometimes',
            'franchise_id' => 'sometimes',
            "mobile_no" => 'sometimes|string',
            'name' => 'sometimes|string',
            'email' => 'sometimes|email|max:254',
            'role' => 'sometimes|string',
            'designation' => 'sometimes|string',
        ]);

        $user->update($request->all());

        return new UserResource($user);
    }

    public function destroy(User $user) {
        $user->delete();

        return response()->json(["message" => "User deleted successfully!"]);
    }
}
