<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use App\Http\Traits\Searchable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Bill extends Model
{
    use SoftDeletes, HasFactory, Searchable, Filterable;

    protected $fillable = [
        'user_id',
        'franchise_id',
        'payment_type_id',
        'order_source_id',
        'table_id',
        'amount',
        'discount',
        'gst',
        'is_parcel',
        'is_active',
    ];

    protected array $searchableFields = [];

    public function user(): BelongsTo {
        return $this->belongsTo(User::class);
    }

    public function franchise(): BelongsTo {
        return $this->belongsTo(Franchise::class);
    }

    public function paymentType(): BelongsTo {
        return $this->belongsTo(PaymentType::class);
    }

    public function orderSource(): BelongsTo {
        return $this->belongsTo(OrderSource::class);
    }

    public function table(): BelongsTo {
        return $this->belongsTo(Table::class);
    }

    public function billDetails(): HasMany {
        return $this->hasMany(BillDetail::class);
    }

    public function parcelDetails(): HasMany {
        return $this->hasMany(ParcelDetail::class);
    }
}
