<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use App\Http\Traits\Searchable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Franchise extends Model
{
    use SoftDeletes, HasFactory, Filterable, Searchable;

    protected $fillable = [
        'master_franchise_id',
        'shop_name',
        'user_name',
        'email',
        'mobile',
        'address',
        'landmark',
        'city',
        'country',
        'state',
        'pincode',
        'gst',
        'cgst',
        'user_contact',
        'user_dob',
        'shop_opening_date',
        'franchise_amount',
        'master_commission_percent',
        'renewal_date',
        'is_master',
        'is_active',
        'is_approved',
    ];

    protected array $searchableFields = [];

    public function masterFranchise(): BelongsTo {
        return $this->belongsTo(MasterFranchise::class);
    }

    public function users(): HasMany {
        return $this->hasMany(User::class);
    }

    public function items(): HasMany {
        return $this->hasMany(Item::class);
    }

    public function purchaseOrders(): HasMany {
        return $this->hasMany(PurchaseOrder::class);
    }
}
