<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Abbasudo\Purity\Traits\Filterable;
use App\Http\Traits\Searchable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;


class User extends Authenticatable
{
    use HasFactory, Notifiable, HasApiTokens, Filterable, Searchable;

    protected $fillable = [
        'master_franchise_id',
        'franchise_id',
        'name',
        'email',
        'email_verified_at',
        'password',
        'role',
        'designation',
        'status',
        'address',
        'mobile_no',
        'city',
        'country',
        'pincode',
        'forget_password_token',
        'is_customer',
        'is_customer_registered',
        'is_blacklisted',
    ];

    protected array $searchableFields = ["name", "email", "role", "mobile_no", "city", "country", "pincode"];

    protected $hidden = [
        'password',
        'remember_token',
    ];

    public function masterFranchise(): BelongsTo {
        return $this->belongsTo(MasterFranchise::class);
    }

    public function franchise(): BelongsTo {
        return $this->belongsTo(Franchise::class);
    }

    protected function casts(): array {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }
}


