<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void {
        Schema::create('users', function (Blueprint $table) {
            $table->id();
            $table->string('name');
            $table->string('email')->unique();
            $table->timestamp('email_verified_at')->nullable();
            $table->string('password');
            $table->string("role")->nullable();
            $table->string("designation")->nullable();
            // TODO: check the value in the database weather it is 0 or else
            $table->text("address")->nullable();
            $table->boolean("status")->default(false);
            $table->string("mobile_no")->nullable();
            $table->string("city")->nullable();
            $table->string("country")->nullable();
            $table->string("pincode")->nullable();
            $table->string("forget_password_token")->nullable();
            $table->boolean("is_customer")->default(false);
            $table->boolean("is_customer_registered")->default(false);
            $table->boolean("is_blacklisted")->default(false);


            $table->foreignId("master_franchise_id")->nullable()
                ->constrained("master_franchises")
                ->cascadeOnDelete()->cascadeOnUpdate();

            $table->foreignId("franchise_id")->nullable()
                ->constrained("franchises")
                ->cascadeOnDelete()->cascadeOnUpdate();

            $table->rememberToken();
            $table->timestamps();
        });

        Schema::create('password_reset_tokens', function (Blueprint $table) {
            $table->string('email')->primary();
            $table->string('token');
            $table->timestamp('created_at')->nullable();
        });
        Schema::create('sessions', function (Blueprint $table) {
            $table->string('id')->primary();
            $table->foreignId('user_id')->nullable()->index();
            $table->string('ip_address', 45)->nullable();
            $table->text('user_agent')->nullable();
            $table->longText('payload');
            $table->integer('last_activity')->index();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void {
        Schema::dropIfExists('users');
        Schema::dropIfExists('password_reset_tokens');
        Schema::dropIfExists('sessions');
    }
};
